@@ -11,20 +11,16 @@ __copyright__ = "Copyright 2012-2013, Georgia Tech Research Corporation"
 __license__ = "BSD-compatible (see LICENSE.txt)"
 
 
-#TODO:
-#  1. Add support to convert units from the data space to the axis space
-#     (utilize the displayUnit value from the trajectory entries).
-
-
 import os
 import numpy as np
-import matplotlib.pyplot as plt
-
 import modelicares.base as base
 
+from scipy.io import loadmat
+from matplotlib.pyplot import figlegend
 from matplotlib import rcParams
 from collections import namedtuple
-from scipy.io import loadmat
+from fnmatch import fnmatchcase
+from difflib import get_close_matches
 
 from modelicares.gui import Browser
 from modelicares.texunit import unit2tex, label_number
@@ -79,7 +75,7 @@ class SimRes(object):
     those results
     """
 
-    def __init__(self, fname='dsres.mat'):
+    def __init__(self, fname='dsres.mat', constants_only=False):
         """On initialization, load Modelica_ simulation results from a
         MATLAB\ :sup:`®` file in Dymola\ :sup:`®` format.
 
@@ -89,12 +85,20 @@ class SimRes(object):
 
              The file extension ('.mat') is optional.
 
+        - *constants_only*: *True*, if only the variables from the first data
+          table should be loaded
+
+             The first data table typically contains all of the constants,
+             parameters, and variables that don't vary.  If only that
+             information is needed, it will save some time and memory to set
+             *constants_only* to *True*.
+
         **Example:**
 
            >>> from modelicares import SimRes
            >>> sim = SimRes('examples/ChuaCircuit.mat')
         """
-        self._load(fname)
+        self._load(fname, constants_only)
 
         # Save the base filename and the directory.
         self.dir, self.fbase = os.path.split(fname)
@@ -170,11 +174,11 @@ class SimRes(object):
           subplots
 
         - *leg_kwargs*: Dictionary of keyword arguments for
-          matplotlib.pyplot.legend
+          :meth:`matplotlib.pyplot.legend`
 
              If *leg_kwargs* is *None*, then no legend will be shown.
 
-        - *\*\*kwargs*: Propagated to :meth:`matplotlib.pyplot.bar`
+        - *\*\*kwargs*: Additional arguments for  :meth:`matplotlib.pyplot.bar`
 
         **Returns:**
 
@@ -214,16 +218,24 @@ class SimRes(object):
             if len(ax) == 1:
                 ax[0].legend(loc=loc, **leg_kwargs)
             else:
-                plt.figlegend(ax[0].lines, **leg_kwargs)
+                figlegend(ax[0].lines, **leg_kwargs)
         return ax
 
-    def _load(self, fname='dsres.mat'):
+    def _load(self, fname='dsres.mat', constants_only=False):
         """Load Modelica_ results from a MATLAB\ :sup:`®` file.
 
         **Arguments:**
 
         - *fname*: Name of the file (may include the path)
 
+        - *constants_only*: *True*, if only the variables from the first data
+          table should be loaded
+
+            The first data table typically contains all of the constants,
+            parameters, and variables that don't vary.  If only that information
+            is needed, it will save some time and memory to set *constants_only*
+            to *True*.
+
         The results are stored within this class as *_traj* and *_data*.
         *_traj* is a dictionary with keywords that correspond to each variable
         name.  The entries are a tuple of (index to the data array, sign of the
@@ -305,31 +317,39 @@ class SimRes(object):
                     data_set, sign_ind = dsres['dataInfo'][0:2, i]
                     description, unit, displayUnit = _parse_description(str(
                         _chars_to_str(dsres['description'][:, i])).rstrip())
-                    self._traj[name] = TrajEntry(data_set=data_set-1,
-                                                 sign=np.sign(sign_ind),
-                                                 data_row=abs(sign_ind)-1,
-                                                 description=description,
-                                                 unit=unit,
-                                                 displayUnit=displayUnit)
+                    if data_set == 1 or not constants_only:
+                        self._traj[name] = TrajEntry(data_set=data_set-1,
+                                                     sign=np.sign(sign_ind),
+                                                     data_row=abs(sign_ind)-1,
+                                                     description=description,
+                                                     unit=unit,
+                                                     displayUnit=displayUnit)
                     if data_set > n_data_sets: n_data_sets = data_set
-                self._data = [dsres['data_%i' % (i+1)]
-                              for i in range(n_data_sets)]
+                if constants_only:
+                    self._data = [dsres['data_1']]
+                else:
+                    self._data = [dsres['data_%i' % (i+1)]
+                                  for i in range(n_data_sets)]
             else:
                 for i in range(dsres['dataInfo'].shape[0]):
                     name = _chars_to_str(dsres['name'][i, :]).rstrip()
                     data_set, sign_ind = dsres['dataInfo'][i, 0:2]
                     description, unit, displayUnit = _parse_description(str(
                         _chars_to_str(dsres['description'][i, :])).rstrip())
-                    self._traj[name] = TrajEntry(data_set=data_set-1,
-                                                 sign=np.sign(sign_ind),
-                                                 data_row=abs(sign_ind)-1,
-                                                 description=description,
-                                                 unit=unit,
-                                                 displayUnit=displayUnit)
+                    if data_set == 1 or not constants_only:
+                        self._traj[name] = TrajEntry(data_set=data_set-1,
+                                                     sign=np.sign(sign_ind),
+                                                     data_row=abs(sign_ind)-1,
+                                                     description=description,
+                                                     unit=unit,
+                                                     displayUnit=displayUnit)
                     if data_set > n_data_sets:
                         n_data_sets = data_set
-                self._data = [dsres['data_%i' % (i+1)].T
-                              for i in range(n_data_sets)]
+                if constants_only:
+                    self._data = [dsres['data_1'].T]
+                else:
+                    self._data = [dsres['data_%i' % (i+1)].T
+                                  for i in range(n_data_sets)]
             # Note 1: The indices are converted from Modelica (1-based) to
             # Python (0-based).
             # Note 2:  Dymola 7.4 uses the transposed version, so it is the
@@ -412,8 +432,8 @@ class SimRes(object):
         """
         try:
             if isinstance(names, basestring):
-                # Note:  This test is explicit (not duck-typing) since a string
-                # is iterable.
+                # This test is explicit (not duck-typing) since a string is
+                # iterable.
                 return attr(names)
             else:
                 attrs = []
@@ -426,7 +446,10 @@ class SimRes(object):
                         attrs.append(a)
                 return attrs
         except KeyError:
-            print('"%s" is not a valid variable name.' % names)
+            print('%s is not a valid variable name.\n' % names)
+            print("Did you mean one of these?")
+            for close_match in get_close_matches(names, self._traj.keys()):
+                print("       " + close_match)
             return
 
     def get_description(self, names):
@@ -680,6 +703,21 @@ class SimRes(object):
            >>> sim = SimRes('examples/ChuaCircuit.mat')
            >>> sim.get_values('L.v') # doctest: +ELLIPSIS
            array([  0.00000000e+00, ... -2.53528625e-01], dtype=float32)
+
+        If the variable cannot be found, then possible matches are listed:
+
+        .. code-block:: python
+
+           >>> sim.get_values(['L.vv']) # doctest: +ELLIPSIS
+           L.vv is not a valid variable name.
+           <BLANKLINE>
+           Did you mean one of these?
+                  L.v
+                  L.p.v
+                  L.n.v
+
+        The other *get_*\* methods also give this message when a variable cannot
+        be found.
         """
         def _get_value(entry):
             """Return the values of a variable given its *_traj* entry.
@@ -694,6 +732,8 @@ class SimRes(object):
         """Return vector(s) of the values of the samples of variable(s) (at
         optionally given times).
 
+        **Arguments:**
+
         - *names*: String or (possibly nested) list of strings of the variable
           names
 
@@ -736,9 +776,25 @@ class SimRes(object):
 
         return self._get(names, _get_value_at_times)
 
+    def keys(self):
+        """Return a list of all variable names.
+
+        This is the same as :meth:`names` and :meth:`variables`.
+
+        **Example:**
+
+           >>> from modelicares import SimRes
+           >>> sim = SimRes('examples/ChuaCircuit.mat')
+           >>> sim.keys()  # doctest: +ELLIPSIS
+           [u'L.p.i', u'Ro.alpha', ... u'Ro.LossPower']
+        """
+        return self._traj.keys()
+
     def names(self):
         """Return a list of all variable names.
 
+        This is the same as :meth:`keys` and :meth:`variables`.
+
         **Example:**
 
            >>> from modelicares import SimRes
@@ -748,6 +804,41 @@ class SimRes(object):
         """
         return self._traj.keys()
 
+    def variables(self):
+        """Return a list of all variable names.
+
+        This is the same as :meth:`keys` and :meth:`names`.
+
+        **Example:**
+
+           >>> from modelicares import SimRes
+           >>> sim = SimRes('examples/ChuaCircuit.mat')
+           >>> sim.variables()  # doctest: +ELLIPSIS
+           [u'L.p.i', u'Ro.alpha', ... u'Ro.LossPower']
+        """
+        return self._traj.keys()
+
+    def glob(self, pattern):
+        """Return a list of variable names that match *pattern*.
+
+        Patterns are Unix shell style:
+
+        *       matches everything
+        ?       matches any single character
+        [seq]   matches any character in seq
+        [!seq]  matches any char not in seq
+
+        The matches are case-sensitive.
+
+        **Example:**
+
+           >>> from modelicares import SimRes
+           >>> sim = SimRes('examples/ChuaCircuit.mat')
+           >>> sim.glob('L.p*')  # doctest: +ELLIPSIS
+           [u'L.p.i', u'L.p.v']
+        """
+        return [key for key in self._traj.keys() if fnmatchcase(key, pattern)]
+
     def nametree(self):
         """Return a tree of all variable names with respect to the path names.
 
@@ -788,8 +879,6 @@ class SimRes(object):
              use_paren=True, **kwargs):
         """Plot data as points and/or curves in 2D Cartesian coordinates.
 
-        A new figure is created if necessary.
-
         **Arguments:**
 
         - *ynames1*: Names of variables for the primary y axis
@@ -870,7 +959,7 @@ class SimRes(object):
            >>> sim.plot(ynames1='L.i', ylabel1="Current",
            ...          ynames2='L.der(i)', ylabel2="Derivative of current",
            ...          title="Chua Circuit", label='examples/ChuaCircuit') # doctest: +ELLIPSIS
-           (<matplotlib.axes.AxesSubplot object at 0x...>, <matplotlib.axes.Axes object at 0x...>)
+           (<matplotlib.axes._subplots.AxesSubplot object at 0x...>, <matplotlib.axes._subplots.AxesSubplot object at 0x...>)
 
            >>> saveall()
            Saved examples/ChuaCircuit.pdf
@@ -878,13 +967,13 @@ class SimRes(object):
 
         .. only:: html
 
-           .. image:: examples/ChuaCircuit.png
+           .. image:: ../examples/ChuaCircuit.png
               :scale: 70 %
               :alt: plot of Chua circuit
 
         .. only:: latex
 
-           .. figure:: examples/ChuaCircuit.pdf
+           .. figure:: ../examples/ChuaCircuit.pdf
               :scale: 70 %
 
               Plot of Chua circuit
@@ -900,8 +989,11 @@ class SimRes(object):
                     descriptions = self.get_description(ynames)
                     # If the descriptions are the same, label the y axis with
                     # the 1st one.
-                    if len(set(descriptions)) == 1:
-                        ylabel = descriptions[0]
+                    ylabel = descriptions[0]
+                    if len(set(descriptions)) <> 1:
+	                    print("The y-axis variable descriptions are not all "
+	                          "the same.  The first has been used.  Please "
+	                          "provide the proper name via ylabel1 or ylabel2.")
                 if legends == []:
                     legends = ynames
                 if incl_prefix:
@@ -913,7 +1005,8 @@ class SimRes(object):
                 units = self.get_unit(ynames)
                 if len(set(units)) == 1:
                     # The  units are the same, so show the 1st one on the axis.
-                    ylabel = label_number(ylabel, units[0])
+                    if ylabel <> "":
+                        ylabel = label_number(ylabel, units[0])
                 else:
                     # Show the units in the legend.
                     if legends:
@@ -944,7 +1037,8 @@ class SimRes(object):
             xlabel = 'Time' if xname == 'Time' else self.get_description(xname)
             # With Dymola 7.4, the description of the time variable will be
             # "Time in", which isn't good.
-        xlabel = label_number(xlabel, self.get_unit(xname))
+        if xlabel <> "":
+            xlabel = label_number(xlabel, self.get_unit(xname))
 
         # Generate the y-axis labels and sets of legend entries.
         ylabel1, legends1 = _ystrings(ynames1, ylabel1, legends1)
@@ -965,7 +1059,7 @@ class SimRes(object):
             if ynames2:
                 # Use solid lines for primary axis and dotted lines for
                 # secondary.
-                kwargs['dashes'] = [(1, 0)]
+                kwargs['dashes'] = [(None, None)]
                 base.plot(y_1, self.get_times(ynames1) if xname == 'Time'
                           else x, ax1, label=legends1, **kwargs)
                 kwargs['dashes'] = [(3, 3)]
@@ -1048,7 +1142,7 @@ class SimRes(object):
         - *hspace*: The amount of height reserved for white space between
           subplots
 
-        - *\*\*kwargs*: Propagated to :class:`matplotlib.sankey.Sankey`
+        - *\*\*kwargs*: Additional arguments for  :class:`matplotlib.sankey.Sankey`
 
         **Returns:**
 
@@ -1080,13 +1174,13 @@ class SimRes(object):
 
         .. only:: html
 
-           .. image:: examples/ThreeTanks.png
+           .. image:: ../examples/ThreeTanks.png
               :scale: 70 %
               :alt: Sankey digarams of three-tank model
 
         .. only:: latex
 
-           .. figure:: examples/ThreeTanks.pdf
+           .. figure:: ../examples/ThreeTanks.pdf
               :scale: 70 %
 
               Sankey digarams of three-tank model
@@ -1146,7 +1240,7 @@ class SimRes(object):
              The default is :meth:`get_values`.  *action* may be a list or
              tuple, in which case the return value is a list or tuple.
 
-        - *\*args*, *\*\*kwargs*: Propagated to *action*
+        - *\*args*, *\*\*kwargs*: Additional arguments for *action*
 
         **Examples:**
 
